# wireguard

![Version: 1.3.3](https://img.shields.io/badge/Version-1.3.3-informational?style=flat-square) ![AppVersion: 1.0.20210424](https://img.shields.io/badge/AppVersion-1.0.20210424-informational?style=flat-square)

Fast, modern, secure VPN tunnel

**This chart is not maintained by the upstream project and any issues with the chart should be raised [here](https://github.com/k8s-at-home/charts/issues/new/choose)**

## Source Code

* <https://github.com/k8s-at-home/container-images>
* <https://github.com/k8s-at-home/charts>

## Requirements

Kubernetes: `>=1.16.0-0`

## Dependencies

| Repository | Name | Version |
|------------|------|---------|
| https://library-charts.k8s-at-home.com | common | 4.4.2 |

## TL;DR

```console
helm repo add k8s-at-home https://k8s-at-home.com/charts/
helm repo update
helm install wireguard k8s-at-home/wireguard
```

## Installing the Chart

To install the chart with the release name `wireguard`

```console
helm install wireguard k8s-at-home/wireguard
```

## Uninstalling the Chart

To uninstall the `wireguard` deployment

```console
helm uninstall wireguard
```

The command removes all the Kubernetes components associated with the chart **including persistent volumes** and deletes the release.

## Configuration

Read through the [values.yaml](./values.yaml) file. It has several commented out suggested values.
Other values may be used from the [values.yaml](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common/values.yaml) from the [common library](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common).

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`.

```console
helm install wireguard \
  --set env.TZ="America/New York" \
    k8s-at-home/wireguard
```

Alternatively, a YAML file that specifies the values for the above parameters can be provided while installing the chart.

```console
helm install wireguard k8s-at-home/wireguard -f values.yaml
```

## Custom configuration

The container in this chart requires the wg0.conf to be in /etc/wireguard
for it to run. Either add it under configSecret or under persistence.

## Values

**Important**: When deploying an application Helm chart you can add more values from our common library chart [here](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common)

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| configSecret | object | base64 encoded wg0.conf by running `base64 wg0.conf` | If set to 'true', the configuration will be read from these values. -- Otherwise you have to mount a volume to /etc/wireguard containing the wg0.conf. |
| configSecret.enabled | bool | `false` | Store Wireguard config as a secret |
| env.IPTABLES_BACKEND | string | `"nft"` | Override the backend used by iptables. Valid values are nft and legacy |
| env.KILLSWITCH | bool | false | Enable a killswitch that kills all trafic when the VPN is not connected |
| env.TZ | string | `"UTC"` | Set the container timezone |
| image.pullPolicy | string | `"IfNotPresent"` | image pull policy |
| image.repository | string | `"ghcr.io/k8s-at-home/wireguard"` | image repository |
| image.tag | string | `"v1.0.20210424"` | image tag |
| ingress.main | object | See values.yaml | Enable and configure ingress settings for the chart under this key. |
| persistence | object | See values.yaml | Configure persistence settings for the chart under this key. |
| probes | object | See values.yaml | Configures the probes for the main Pod. |
| securityContext | object | see values.yaml | Security contexts required for container. |
| service | object | See values.yaml | Configures service settings for the chart. |

## Changelog

### Version 1.3.3

#### Added

N/A

#### Changed

* Upgraded `common` chart dependency to version 4.4.2

#### Fixed

N/A

### Older versions

A historical overview of changes can be found on [ArtifactHUB](https://artifacthub.io/packages/helm/k8s-at-home/wireguard?modal=changelog)

## Support

- See the [Docs](https://docs.k8s-at-home.com/our-helm-charts/getting-started/)
- Open an [issue](https://github.com/k8s-at-home/charts/issues/new/choose)
- Ask a [question](https://github.com/k8s-at-home/organization/discussions)
- Join our [Discord](https://discord.gg/sTMX7Vh) community

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v0.1.1](https://github.com/k8s-at-home/helm-docs/releases/v0.1.1)
